@@ -441,8 +441,10 @@ load_scalar(perl_yaml_loader_t *loader)
             if (loader->load_blessed)
                 scalar = sv_setref_pvn(newSV(0), class, string, strlen(string));
             else
-                scalar = sv_setref_pvn(newSV(0), NULL, string, strlen(string));
+                scalar = newSVpvn(string, length);
             SvUTF8_on(scalar);
+            if (anchor)
+                hv_store(loader->anchors, anchor, strlen(anchor), SvREFCNT_inc(scalar), 0);
             return scalar;
         }
     }
